summaryrefslogtreecommitdiffstats
path: root/cpukit/score/src/coretodtickle.c
diff options
context:
space:
mode:
Diffstat (limited to 'cpukit/score/src/coretodtickle.c')
-rw-r--r--cpukit/score/src/coretodtickle.c15
1 files changed, 7 insertions, 8 deletions
diff --git a/cpukit/score/src/coretodtickle.c b/cpukit/score/src/coretodtickle.c
index 1afef420a2..f4e5a4f69c 100644
--- a/cpukit/score/src/coretodtickle.c
+++ b/cpukit/score/src/coretodtickle.c
@@ -19,7 +19,7 @@
#include <rtems/system.h>
#include <rtems/score/object.h>
#include <rtems/score/thread.h>
-#include <rtems/score/timespec.h>
+#include <rtems/score/timestamp.h>
#include <rtems/score/tod.h>
#include <rtems/score/watchdog.h>
@@ -36,22 +36,21 @@
void _TOD_Tickle_ticks( void )
{
- struct timespec tick;
- uint32_t seconds;
+ Timestamp_Control tick;
+ uint32_t seconds;
- /* Convert the tick quantum to a timespec */
- tick.tv_nsec = _TOD_Microseconds_per_tick * 1000;
- tick.tv_sec = 0;
+ /* Convert the tick quantum to a timestamp */
+ _Timestamp_Set( &tick, 0, _TOD_Microseconds_per_tick * 1000 );
/* Update the counter of ticks since boot */
_Watchdog_Ticks_since_boot += 1;
/* Update the timespec format uptime */
- (void) _Timespec_Add_to( &_TOD_Uptime, &tick );
+ _Timestamp_Add_to( &_TOD_Uptime, &tick );
/* we do not care how much the uptime changed */
/* Update the timespec format TOD */
- seconds = _Timespec_Add_to( &_TOD_Now, &tick );
+ seconds = _Timestamp_Add_to_at_tick( &_TOD_Now, &tick );
while ( seconds ) {
_Watchdog_Tickle_seconds();
seconds--;